@@ -58,6 +58,7 @@ return array(
 					'type' => 'string',
 					'string_type' => 'dir',
 					'default' => 'Maildir',
+					'string_emptyallowed' => true,
 					'save_method' => 'storeSettingField',
 					),
 				'panel_sendalternativemail' => array(
@@ -84,21 +85,6 @@ return array(
 					'default' => 100,
 					'save_method' => 'storeSettingField',
 					),
-				'system_autoresponder_enabled' => array(
-					'label' => $lng['serversettings']['autoresponder_active'],
-					'settinggroup' => 'autoresponder',
-					'varname' => 'autoresponder_active',
-					'type' => 'bool',
-					'default' => false,
-					'cronmodule' => 'froxlor/autoresponder',
-					'save_method' => 'storeSettingField',
-					),
-				'system_last_autoresponder_run' => array(
-					'settinggroup' => 'autoresponder',
-					'varname' => 'last_autoresponder_run',
-					'type' => 'hidden',
-					'default' => 0,
-					),
 				'system_catchall_enabled' => array(
 					'label' => $lng['serversettings']['catchall_enabled'],
 					'settinggroup' => 'catchall',
@@ -107,6 +93,54 @@ return array(
 					'default' => true,
 					'save_method' => 'storeSettingResetCatchall',
 					),
+				'system_mailtraffic_enabled' => array(
+					'label' => $lng['serversettings']['mailtraffic_enabled'],
+					'settinggroup' => 'system',
+					'varname' => 'mailtraffic_enabled',
+					'type' => 'bool',
+					'default' => true,
+					'save_method' => 'storeSettingField',
+					),
+				'system_mdaserver' => array(
+					'label' => $lng['serversettings']['mdaserver'],
+					'settinggroup' => 'system',
+					'varname' => 'mdaserver',
+					'type' => 'option',
+					'option_mode' => 'one',
+					'default' => 'dovecot',
+					'option_options' => array('courier' => 'Courier', 'dovecot' => 'Dovecot'),
+					'save_method' => 'storeSettingField',
+					),
+				'system_mdalog' => array(
+					'label' => $lng['serversettings']['mdalog'],
+					'settinggroup' => 'system',
+					'varname' => 'mdalog',
+					'type' => 'string',
+					'string_type' => 'file',
+					'default' => '/var/log/mail.log',
+					'string_emptyallowed' => true,
+					'save_method' => 'storeSettingField',
+					),
+				'system_mtaserver' => array(
+					'label' => $lng['serversettings']['mtaserver'],
+					'settinggroup' => 'system',
+					'varname' => 'mtaserver',
+					'type' => 'option',
+					'option_mode' => 'one',
+					'default' => 'postfix',
+					'option_options' => array('exim4' => 'Exim4', 'postfix' => 'Postfix'),
+					'save_method' => 'storeSettingField',
+					),
+				'system_mtalog' => array(
+					'label' => $lng['serversettings']['mtalog'],
+					'settinggroup' => 'system',
+					'varname' => 'mtalog',
+					'type' => 'string',
+					'string_type' => 'file',
+					'default' => '/var/log/mail.log',
+					'string_emptyallowed' => true,
+					'save_method' => 'storeSettingField',
+					),
 				),
 			),
 		),
