@@ -17,7 +17,10 @@
  *
  */
 
-if ($settings['logger']['log_cron'] == '1') {
+// check for cron.d-generation task and create it if necessary
+checkCrondConfigurationFile();
+
+if (Settings::Get('logger.log_cron') == '1') {
 	$cronlog->setCronLog(0);
 	fwrite($debugHandler, 'Logging for cron has been shutdown' . "\n");
 }
