@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
@@ -32,7 +32,7 @@
 
 function makeyesno($name, $yesvalue, $novalue = '', $yesselected = '', $disabled = false)
 {
-	global $lng;
+	global $lng, $theme;
 	
 	if($disabled) {
 		$d = ' disabled="disabled"';
